Learn R Programming

VdgRsm (version 1.4)

Borkowski2003: Small Exact D-, A-, G-, and IV-Optimal Designs

Description

Retrieve small exact D-, A-, G-, and IV-Optimal designs generated by a genetic algorithm. These designs are catalogued by Borkowski (2003).

Usage

Borkowski2003(criterion, k, N)

Arguments

criterion
Only optimal criteria "D", "A", "G", and "IV" are available now.
k
The number of factor, k = 2 and 3
N
The number of design points

Value

  • Borkowski2003 is called to generate the data frame of the design matrix of the optimal designs.

References

Borkowski, J. J. (2003). Using a Genetic Algorithm to Generate Small Exact Response Surface Designs. Journal of Probability and Statistical Science, 1(1):65-88.

Examples

Run this code
Borkowski2003("D", 2, 10)
  Borkowski2003("G", 3, 13)
  Borkowski2003("IV", 2, 7)
  Borkowski2003("A", 3, 15)

Run the code above in your browser using DataLab