design.matrix, design.matrix.2, design.matrix.3
Data frames of design points to be compared in coded or uncoded units. There should be one column for each factor in the design, and one row for each run in the design. The maximum number of factors is 7.
label
The default is "ON" meaning that all legends will be appeared, and if it is "OFF", legends will be removed.