Learn R Programming

VdgRsm (version 1.5)

gen.HSCD: Hartley's Small Composite Designs (HSCDs)

Description

Generate Hartley's small composite designs for k = 2 to 7

Usage

gen.HSCD(k, alpha ="rotatable", n.center = 0)

Arguments

k
The number of factors or independent variables, k = 2, 3, 4, 5, 6, and 7.
alpha
Axial distance. User may specify "rotatable", "face-center", or other numeric numbers. See examples.
n.center
The number of center points

Value

gen.HSCD is called to generate the data frame of the design matrix of the HSCD

References

SAS 9.1 ADX Interface for Design of Experiments. Cary, NC: SAS Institute Inc.

Examples

Run this code
  gen.HSCD(3)
  gen.HSCD(4, alpha ="face-center")
  gen.HSCD(7, alpha = 2, n.center = 4)

Run the code above in your browser using DataLab