Learn R Programming

VdgRsm (version 1.5)

gen.PBCD: Plackett-Burman Composite Designs (Draper and Lin's Method)

Description

Generate Plackett-Burman composite designs proposed by Draper and Lin (1990) for k = 3 to 7

Usage

gen.PBCD(k, alpha ="rotatable", n.center = 0)

Arguments

k
The number of factors or independent variables, k = 3 to 7.
alpha
Axial distance. User may specify "rotatable", "face-center", or other numeric numbers. See examples.
n.center
The number of center points

Value

gen.PBCD is called to generate the data frame of the design matrix of the PBCD

References

SAS 9.1 ADX Interface for Design of Experiments. Cary, NC: SAS Institute Inc.

Examples

Run this code
 gen.PBCD(3)
 gen.PBCD(4, alpha = 1)
 gen.PBCD(5, alpha = "face-center", n.center = 3)
 gen.PBCD(6, alpha = 2, n.center = 5)

Run the code above in your browser using DataLab