Learn R Programming

VdgRsm (version 1.4)

gen.Roquemore: Roquemore's Hybrid Designs

Description

Generate Roquemore (1976) hybrid designs for k = 3, 4, and 6. For k = 3, R310, R311A, and R311B will be produced, for k = 4, R416A, R416B, and R416C will be generated, and for k = 6 R628A and R628B will be given.

Usage

gen.Roquemore(k, n.center = 0)

Arguments

k
The number of factors or independent variables, k = 3, 4, and 6.
n.center
The number of center points

Value

  • gen.Roquemore will retrieve the hybrid design stored and the output is a list containing relevant Roquemore's designs given a k value.

References

SAS 9.1 ADX Interface for Design of Experiments. Cary, NC: SAS Institute Inc.

Examples

Run this code
gen.Roquemore(3)
 gen.Roquemore(4, n.center = 2)
 gen.Roquemore(6, n.center = 1)

Run the code above in your browser using DataLab