Learn R Programming

VdgRsm (version 1.4)

gen.USD: Doehlert's Uniform Shell Designs (USDs)

Description

Generate uniform shell designs for k = 2 to 6

Usage

gen.USD(k, alpha = 1)

Arguments

k
The number of factors or independent variables, k = 2 to 6.
alpha
A scaling factor. See examples.

Value

  • gen.USD is called to generate the data frame of the design matrix of the USD.

References

Doehlert, D. H (1970), Uniform Shell Designs, Journal of the Royal Statistical Society, 19(3):231-239

Examples

Run this code
gen.USD(2)
  gen.USD(3, alpha = sqrt(3))
  gen.USD(6)
  gen.USD(6, alpha = sqrt(6))

Run the code above in your browser using DataLab