Learn R Programming

VdgRsm (version 1.4)

spvcontour: Contour Plot of Scaled Prediction Variances

Description

Create a contour plot of scaled prediction variances

Usage

spvcontour(design.matrix, shape, max.radius = sqrt(2), length = 100, 
  nlevels = 10, title = "Contour of SPVs")

Arguments

design.matrix
A data frame of design points. There should be one column for each factor in the design, and one row for each run in the design. Only design with 2 factors is allowed.
shape
The shape can be "circle" or "square" which represent a shape of design space.
max.radius
The radius of a circle.
length
Argument from interp from library akima.
nlevels
Argument from interp from library akima.
title
The title of a contour plot.

Value

  • spvcontour is called to generate a contour plot of scaled prediction variances for response surface designs.

Examples

Run this code
library(akima)
  CCD1<- gen.CCD(n.vars = 2, n.center = 2, alpha = 1)
  spvcontour(CCD1, shape = "square")
  CCD2<-gen.CCD(n.var = 2, alpha = sqrt(2), n.center = 3)
  spvcontour(CCD2, shape = "circle")
  spvcontour(CCD2, shape = "circle", length = 200)
  spvcontour(CCD2, shape = "circle", length = 200, nlevels = 20)

Run the code above in your browser using DataLab