Borkowski2003: Small Exact D- and A-Optimal Designs
Description
Retrieve small exact D- and A-optimal designs generated by a genetic algorithm provided by Borkowski (2003)
Usage
Borkowski2003(criterion, k, N)
Arguments
criterion
Only optimal criteria "D" and "A" are available now.
k
The number of factor, k = 2 and 3
N
The number of design points
Value
Borkowski2003 is called to generate the data frame of the design matrix of the optimal designs.
References
Borkowski, J. J. (2003). Using a Genetic Algorithm to Generate Small Exact Response Surface Designs. Journal of Probability and Statistical Science, 1(1):65-88.