Learn R Programming

VdgRsm (version 1.02)

VdgRsm-package: Variance Dispersion and Fraction of Design Space Plots

Description

This package creates variance dispersion graphs (VDGs), fraction of design space (FDS) plots for second-order model designs in spherical and cuboidal regions, and also generates central composite and factorial designs.

Arguments

Details

ll{ Package: VdgRsm Type: Package Version: 1.02 Date: 2014-10-11 License: GPL-2 }

References

1. Borkowski J.J. (2005), Chapter 14: "Graphical Methods for Assessing the Prediction Capability of Response Surface Designs" In Khuri, A.I., "Response Surface Methodology and Related Topics", p.349-375, World Scientific Publishing. 2. Giovannitti-Jensen, A. and Myers, R.H. (1989), "Graphical Assessment of the Prediction Capability of Response Surface Designs", Technometrics, 31, p.159-171. 3. Khuri, A.I., Kim, H.J., and Um Y. (1996), "Quantile plots of the prediction variance for response surface designs", Computational Statistics and Data Analysis, 22, p.395-407. 4. Nguyen, N.K. and Borkowski, J.J. (2008), "New 3-Level Response Surface Designs Constructed from Incomplete Block Designs", Journal of Statistical Planning and Inference, 138, p.294-305. 5. Rozum, M.A. and Myers, R.H. (1991), "Adaptation of Variance Dispersion Graphs to Cuboidal Regions of Interest", Presented at Joint Statistical Meetings, American Statistical Association, Atlanta, GA. 6. Zahran, A., Anderson-Cook, C.M., and Myers, R.H. (2003), "Fraction of Design Space to Assess the Prediction Capability of Response Surface Designs", Journal of Quality Technology, 35, p.377-386.

See Also

The CRAN task view on Design of Experiments