Learn R Programming

VdgRsm (version 1.02)

gen.CCD: Central Composite Designs

Description

Generate central composite designs

Usage

gen.CCD(n.vars, n.center, alpha, varNames)

Arguments

n.vars
The number of factors or independent variables
n.center
The number of center points
alpha
The axial distance
varNames
The variable names. If it is not provided, the default names are X1,X2,...,Xk

Value

  • gen.CCD is called to generate the data frame of the design matrix of the CCD

Examples

Run this code
CCD1<- gen.CCD(n.vars = 3, n.center = 2, alpha = 1)
  CCD2<- gen.CCD(n.vars = 3, n.center = 2, alpha = 1, varNames = c("T1","T2","T3"))

Run the code above in your browser using DataLab